Crate binconf

Crate binconf 

Enums

ConfigError
ConfigLocation
ConfigType

Traits

Decode
A type which can be decoded from bytes with decode.
DecodeOwned
A type which can be decoded without borrowing any bytes from the input.
Encode
A type which can be encoded to bytes with encode.

Functions

get_configuration_path
Get the configuration file path used by load and store functions.
load_bin
Loads a config file from the config, cache, cwd, or local data directory of the current user. In binary format.
load_bin_skip_check
Loads a config file from the config, cache, cwd, or local data directory of the current user. Without verifying the hash. In binary format.
load_json
Loads a config file from the config, cache, cwd, or local data directory of the current user. In json format.
load_ron
Loads a config file from the config, cache, cwd, or local data directory of the current user. In ron format.
load_toml
Loads a config file from the config, cache, cwd, or local data directory of the current user. In toml format.
load_yaml
Loads a config file from the config, cache, cwd, or local data directory of the current user. In yaml format.
store_bin
Stores a config file in the config, cache, cwd, or local data directory of the current user. In binary format.
store_json
Stores a config file in the config, cache, cwd, or local data directory of the current user. In json format.
store_ron
Stores a config file in the config, cache, cwd, or local data directory of the current user. In ron format.
store_toml
Stores a config file in the config, cache, cwd, or local data directory of the current user. In toml format.
store_yaml
Stores a config file in the config, cache, cwd, or local data directory of the current user. In yaml format.

Derive Macros

Decode
Encode